ISO 8601 Dates and Times
========================

.. py:module:: pyslet.iso8601

This module defines special classes for handling ISO 8601 dates
and times.


..	autoclass:: Date
	:members:
	:show-inheritance:

..	autoclass:: Time
	:members:
	:show-inheritance:

..	autoclass:: TimePoint
	:members:
	:show-inheritance:

..	autoclass:: Duration
	:members:
	:show-inheritance:


Supporting Constants
--------------------

..	autoclass:: Truncation
	:members:

..	autodata:: NoTruncation

..	autoclass:: Precision
	:members:


Utility Functions
-----------------

..	autofunction::	leap_year

..	autofunction::	day_of_week

..	autofunction::	week_count

..  autofunction::  get_local_zone
